' -------------------------------------------
' ATI Tool log file script v0.2
' -------------------------------------------
'
' by NeM (nem@samurize.com)
'
' Reports data about ATI graphics cards using
' the ATI Tool log file.
'
' *******************************************************
' **** NOTE!!!!!! ****
' Be sure to set the path to your ATI Tool logfile below!
' *******************************************************
'
' Use the appropriate functions :)
'
' The GetInfo function accepts a format string
' which makes the following substitutions:
'
' %cpu
'   CPU clock speed
'   
' %mem
'   Memory clock speed
'
' %prof
'   Current profile
'
' %chip
'   Graphics chip
'
' %ram
'   Memory
'
' %tempchip
'   whether or not the card has a temperature
'   chip
'
' %pipe
'   number of pipelines
'
' %app
'   the last application run
'
' %gputemp
'   the GPU temperature
'
' %envtemp
'   the GPU environment temperature
'
' Changes in v0.2:
' ----------------
'  - CPU/environment temperatures
'  - new ATI tool log format supported
'
' -------------------------------------------

' ===========================================
' path to your ATI log file
FILENAME = "C:\program files\ATI Tool\log.txt"

' display for unavailable stats
UNKNOWN = "unknown"
' ===========================================

Function StatusReport
    dim formatstring
    formatstring = "Chip: %chip" & vbCrLf & "Memory: %ram" & vbCrLf & "Current Profile: %prof" &  vbCrLf & "Current clock speeds: %cpu / %mem" & vbCrLf & "Pipelines: %pipe" & vbCrLf & "Temperature Chip: %tempchip" & vbCrLf & "Current Application: %app" & vbCrLf & "GPU Temp: %gputemp" & vbCrLf & "Env Temp: %envtemp"
    StatusReport = getInfo(formatstring)
End Function

Function CPUClockSpeed
    CPUClockSpeed = getInfo("%cpu")
End Function

Function MemClockSpeed
    MemClockSpeed = getInfo("%mem")
End Function

Function CurrentProfile
    CurrentProfile = getInfo("%prof")
End Function

Function Chip
    Chip = getInfo("%chip")
End Function

Function Memory
    Memory = getInfo("%ram")
End Function

Function HasTemperatureChip
    HasTemperatureChip = getInfo("%tempchip")
End Function

Function Pipelines
    Pipelines = getInfo("%pipe")
End Function

Function CurrentApplication
    CurrentApplication = getInfo("%app")
End Function

Function GetGPUTemperature
    GetGPUTemperature = getInfo("%gputemp")
End Function    

Function GetEnvTemperature
    GetEnvTemperature = getInfo("%envtemp")
End Function   

Function getInfo(pattern)
    Dim data, re, matches, match
    Data = readFile(FILENAME)
    
    Set re = New RegExp
    
    ' cpu/mem clock info
    With re
        .Pattern = "Clocks set to:\s*(\d*\.\d*) / (\d*\.\d*)"
        .IgnoreCase = True
        .Global = True
    End With
    Set matches = re.Execute(Data)
    if matches.count > 0 then
        Set match = matches.item(matches.count-1)
        CPUClockSpeedVar = match.submatches(0)
        MemClockSpeedVar = match.submatches(1)
    Else
        ' NEW
        re.Pattern = "Core:\s*(\d*\.\d*) Mhz\s*Memory:\s*(\d*\.\d*)"
        Set matches = re.Execute(Data)
        if matches.count > 0 then
            Set match = matches.item(matches.count-1)
            CPUClockSpeedVar = match.submatches(0)
            MemClockSpeedVar = match.submatches(1)
        else
            CPUClockSpeedVar = UNKNOWN
            MemClockSpeedVar = UNKNOWN
        end if
    
    End If
    
    ' profile name
    re.Pattern = "Profile '(.*?)' loaded"
    set matches = re.Execute(Data)
    if matches.count > 0 then
        set match = matches.item(matches.count-1)
        Profile = match.submatches(0)
    else
        Profile = "none found"
    end if
    
    ' chip info
    re.Pattern = "Detected Chip: (.*?)\n"
    set matches = re.Execute(Data)
    if matches.count > 0 then
        set match = matches.item(matches.count-1)
        myarray = split(match.submatches(0), ",")

        ChipVar = Trim(myarray(0))
        
        re.Pattern = "(\d*) Pipelines"
        set matches = re.Execute(trim(myarray(1)))
        set match = matches(0)
        PipelinesVar = match.submatches(0)
        
        MemoryVar = Trim(myarray(2))
        
        re.Pattern = "Tempchip: (.*)"
        set matches = re.Execute(Replace(Trim(myarray(3)),vbCr,""))
        set match = matches(0)
        TempChipVar = match.submatches(0)
    
    Else
        ' NEW
        re.Pattern = "Detected GPU Chip: (.*?)\n"
        set matches = re.Execute(Data)
        
        TempChipVar = UNKNOWN
        if matches.count > 0 then
            set match = matches.item(matches.count-1)
            myarray = split(match.submatches(0), ",")
    
            ChipVar = Trim(myarray(0))
            
            re.Pattern = "(\d*) Pipelines"
            set matches = re.Execute(trim(myarray(1)))
            set match = matches(0)
            PipelinesVar = match.submatches(0)
            
            MemoryVar = Trim(replace(myarray(2),vbCr,""))
            
            

        Else
            MemoryVar = UNKNOWN
            PipelinesVar = UNKNOWN
            ChipVar = UNKNOWN
        End If
        
        
        
    End If
    
    ' latest application
    CurrentApp = UNKNOWN
    re.Pattern = "Application[^\n]*?start.*?\n"
    set Matches = re.Execute(Data)
    if matches.count > 0 then
        set match = matches.item(matches.count-1)
        LastApp = match.value
        re.Pattern = "'(.*?)'"
        set Matches = re.Execute(LastApp)
        if matches.count > 0 then
            set match = matches.item(matches.count-1)
            CurrentApp = match.submatches(0)
        End If
    End If
    
    ' temperatures
    re.Pattern = "Temperature:\s*GPU:\s*(\d*\.\d*).*?GPU environment:\s*(\d*\.\d*)"
    set Matches = re.Execute(Data)
    if matches.count > 0 then
        set match = matches.item(matches.count-1)
        GPUTemp = match.submatches(0)
        EnvTemp = match.submatches(1)
        TempChipVar = "yes"
    else
        EnvTemp = UNKNOWN
        GPUTemp = UNKNOWN
        TempChipVar = "no"
    end if
    

    ' format return string
    pattern = replace(pattern, "%cpu", CPUClockSpeedVar)
    pattern = replace(pattern, "%mem", MemClockSpeedVar)
    pattern = replace(pattern, "%prof", Profile)
    pattern = replace(pattern, "%chip", ChipVar)
    pattern = replace(pattern, "%ram", MemoryVar)
    pattern = replace(pattern, "%tempchip", TempChipVar)
    pattern = replace(pattern, "%pipe", PipelinesVar)
    pattern = replace(pattern, "%app", CurrentApp)
    pattern = replace(pattern, "%envtemp", EnvTemp)
    pattern = replace(pattern, "%gputemp", GPUTemp)
    
    
    getinfo = pattern
    
    set matches = nothing
    set match = nothing
    set re = nothing
End Function




Private Function readFile(fileName)

	dim contents

	Set fs = CreateObject ("Scripting.FileSystemObject")
        If (fs.FileExists(fileName)) Then
		Set filePath = fs.GetFile(fileName)
		set File = filePath.OpenAsTextStream (1, -2)

		contents = file.readall

		File.Close
		Set filePath = nothing
		Set fs = nothing
		Set File = nothing
	Else 	
		readFile = "File doesn't exist"
		Exit Function
        End If

	' return file contents
	readFile = contents

End Function